A preferred time interval can be selected by defining the starting and ending time. The function setwd() is recommended to use beforhand to specify the path to the preferred folder.
1 | EPAdownload(start.time, end.time = NULL, epa.site = NULL, outputname = "EPA")
|
start.time |
The starting time of data downloaded. The date format follows "YYYY-mm-dd HH:MM". Nevertheless, formats including "YYYY", "YYYY-mm", and "YYYY-mm-dd" are also feasible. Note that data is only available since July, 1982. |
end.time |
The ending time of data downloaded. The date format follows "YYYY-mm-dd HH:MM". Nevertheless, formats including "YYYY", "YYYY-mm" are also feasible. The default is current local time. |
epa.site |
One or more than one EPA site can be selected by inputting its Chinese name. The default is all sites. |
outputname |
The name of the output file. The default is "EPA". |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.